@@ -2,8 +2,8 @@
 OpengateM - a MAC address authentication system
  module to control management database
 
- list of mac addresses
- list of usage log
+ table for the list of mac addresses
+ table for the list of usage log
  implemented with MySql 
 
 Copyright (C) 2011 Opengate Project Team
@@ -121,7 +121,7 @@ int queryMacFromMngDb(char* macAddress, char* userId, char* extraId){
 }
 
 /******************************************
-put open log to management db 
+put gate-open log to management db 
 ******************************************/
 int putOpenToMngDb(char* macAddress){
 
@@ -149,7 +149,7 @@ int putOpenToMngDb(char* macAddress){
 }
 
 /******************************************
-put close log to management db
+put gate-close log to management db
 ******************************************/
 int putCloseToMngDb(char* macAddress){
 
@@ -201,7 +201,11 @@ int putMacIpPairToMngDb(char* macAddress, char* ipAddress){
 
 /*******************************************
  get next mac address from watchlist table in management db
- if end of list, return false
+ (watchlist is the list of mac addresses needed specific reporting, 
+  it is needless in normal condition. )
+ the first call of this fuction executes query command and gets the first row 
+ the following call gets the next row of the first call result
+ if end of row, return false
 *******************************************/
 int getNextRecordFromWatchlistTableInMngDb(char* macAddress){
 
