@@ -95,7 +95,7 @@ typedef	void	Sigfunc(int);	/* for signal handlers */
 #define AVOID_OVERLAP 0
 #define ALLOW_OVERLAP 1
 
-extern int debug;
+extern int debug;  /* debug status read from conf file */
 
 /**********prototypes***************************************/
 
@@ -240,3 +240,6 @@ void InitWatchlistCache(void);
 int AddWatchlistCacheItem(char* macAddress);
 int IsFoundInWatchlistCache(char* macAddress);
 void FreeWatchlistCache(void);
+
+/* signal.c */
+Sigfunc* signalx(int signo, Sigfunc* func);
