@@ -28,7 +28,7 @@ static int sqliteBusyTimeout=100;  /* value used in sqite3_busy_timeout() */
 static sqlite3 *dbMd; /* handle for opengatemd.db */
 
 /*******************************************************************
- read sqlite busy timeout value from conf and set to static variable
+ read sqlite busy timeout value from conf and set it to static variable
 *******************************************************************/
 int setupSqliteBusyTimeoutValue(void){
 
@@ -48,7 +48,7 @@ int initWorkDb(void){
 
   char *pErrMsg=NULL;
 
-  /* SQL CREATE COMMAND */
+  /* SQL CREATE TABLE COMMANDs */
   char *createCmd1="CREATE TABLE IF NOT EXISTS sessionmd "
     "(macAddress TEXT PRIMARY KEY, "
     "userId TEXT, extraId TEXT, openTime INTEGER, checkTime INTEGER, "
@@ -60,7 +60,7 @@ int initWorkDb(void){
     "(macAddress TEXT, "
     "ipAddress TEXT, findTime INTEGER)";
 
-  /* setup static variable value for SqLite3_busy_timeout from conf */
+  /* setup SqLite3_busy_timeout read from conf */
   SetupSqliteBusyTimeoutValue();
 
   /* Open sqlite */
@@ -103,7 +103,7 @@ int finalizeWorkDb(void){
 }
 
 /************************************************************
- insert session info to db at start     
+ insert session-info to work db at starting session
 ************************************************************/
 int insertSessionToWorkDb(char* macAddress, char* userId, char* extraId, 
 			int ruleNumber){
@@ -135,7 +135,7 @@ int insertSessionToWorkDb(char* macAddress, char* userId, char* extraId,
 }
 
 /*************************************************************
- update checkTime to time now
+ update checkTime to now
 *************************************************************/
 int updateCheckTimeInWorkDb(char* macAddress){
 
@@ -163,7 +163,7 @@ int updateCheckTimeInWorkDb(char* macAddress){
 }
 
 /*************************************************************
- delete session info in db at stop     
+ delete session-info in work db at stop session
 *************************************************************/
 int delSessionFromWorkDb(char* macAddress){
 
@@ -190,7 +190,7 @@ int delSessionFromWorkDb(char* macAddress){
 }
 
 /************************************************
- get info for active session about mac addr from db  
+ get session-info from work db  
 input = macAddress, output = others
 *************************************************/
 int getSessionFromWorkDb(char* macAddress, char* userId, char* extraId, 
@@ -246,10 +246,11 @@ int getSessionFromWorkDb(char* macAddress, char* userId, char* extraId,
 
 
 /************************************************
- close session that exceed time limit  
- 1. select the record to close firewall 
- 2. delete the record
-if delayed=FALSE, close all sessions without delay 
+ close sessions that exceed time limit  
+ 1. select timeover records and close the firewall 
+ 2. delete the records
+if delayed=FALSE, close all sessions without delay
+if delayed=TRUE, close sessions that exceed time limit 
 *************************************************/
 int delUselessSessionsInWorkDb(int delayed){
 
@@ -273,7 +274,7 @@ int delUselessSessionsInWorkDb(int delayed){
   /* prepare command string for select */
   selectCmd=sqlite3_mprintf(selectFormat, uselessLimitTime);
 
-  /* exec command, callback function = CloseSession */
+  /* exec command, callback function = CloseSession() */
   if(sqlite3_exec(dbMd, selectCmd, CloseSession, NULL, &pErrMsg)!=SQLITE_OK){
     resultFlag=FALSE;
     err_msg("ERR at %s#%d: sqlite_exec:%s",__FILE__,__LINE__, pErrMsg);
@@ -296,7 +297,7 @@ int delUselessSessionsInWorkDb(int delayed){
 }
 
 /************************************************
-get list of sessions from DB and create hash table
+get list of sessions from work DB and create hash table of sessions
 for opengatemd 
  key=macAddress, value=0 
 *************************************************/
@@ -343,8 +344,8 @@ int getSessionTableFromWorkDb(DB* sessionTable){
 
 
 /**********************************
- put out detected mac info to macinfo table in work db
-for checking nat 
+ put out detected mac related info to macinfo table in work db
+ it is used at checking nat 
 **********************************/
 int putMacInfoToWorkDb(char* macAddress, int ttl, int isNat){
 
@@ -375,7 +376,7 @@ int putMacInfoToWorkDb(char* macAddress, int ttl, int isNat){
 
 
 /**********************************
- get mac info from macinfo table in work db 
+ get mac related info from macinfo table in work db 
 **********************************/
 int getMacInfoFromWorkDb(char* macAddress, char* detectTimeStr, int* pTtl){
 
@@ -525,7 +526,8 @@ int putMacIpPairToWorkDb(char* macAddress, char* ipAddress){
 }
 
 /********************************************
-Delete the mac-ip pairs in work db for the mac
+Delete the mac-ip pairs in work db
+input=macAddress only
 ********************************************/
 int delMacIpPairsInWorkDb(char* macAddress){
   char *pErrMsg=NULL;
