@@ -1,10 +1,10 @@
 /**************************************************
 OpengateM - MAC address authentication system 
 
- module to control management database
- list of mac addresses
- list of usage log
- implemented with MySql 
+ module to control management database that includes following tables
+  list of mac addresses and their owners
+  list of usage log
+ this database is implemented with MySql 
 
 Copyright (C) 2011 Opengate Project Team
 Written by Yoshiaki Watanabe
@@ -30,12 +30,12 @@ Email: watanaby@is.saga-u.ac.jp
 
 MYSQL mysql;
 
-/******************************************
-initialize management db
-******************************************/
+/*****************************/
+/* initialize management db  */
+/*****************************/
 int initMngDb(void){
 
-  /* set parameters */
+  /* set parameters read from conf file */
   char *server = GetConfValue("MySqlDb/Server");
   char *user =  GetConfValue("MySqlDb/User");
   char *password = GetConfValue("MySqlDb/Password");
@@ -65,18 +65,19 @@ int initMngDb(void){
   return TRUE;
 }
 
-/******************************************
-close management db
-******************************************/
+/**********************************/
+/*close management db             */
+/**********************************/
 void closeMngDb(void){
   mysql_close(&mysql);
   mysql_library_end();
 }
 
 
-/******************************************
- get nic vendor from management db
-******************************************/
+/*********************************************************/
+/* get nic vendor from table nicvendors in management db */
+/* macAddress:(in),vendor:(out),bufferLength:(in)        */ 
+/*********************************************************/
 int getNicVendorFromMngDb(char* macAddress, char* vendor, int bufferLength){
 
   MYSQL_RES *res;
@@ -85,11 +86,13 @@ int getNicVendorFromMngDb(char* macAddress, char* vendor, int bufferLength){
   char queryStr[BUFFMAXLN];
   char macHeader[ADDRMAXLN];
 
-  /* set default values */
+  /* set default values (="?") */
   vendor[0]='?';
   vendor[1]='\0';
  
   /* prepare query string */
+  /* macHeader is first 3 bytes of macAddess that represents vender code */
+  /* macAddress="11:22:33:44:55:66" -> macHeader="11:22:33" */
   strlcpy(macHeader, macAddress, ADDRMAXLN);
   macHeader[8]='\0';
   snprintf(queryStr, BUFFMAXLN, 
@@ -102,28 +105,30 @@ int getNicVendorFromMngDb(char* macAddress, char* vendor, int bufferLength){
 	     mysql_error(&mysql));
      return FALSE;
   }
-
   res = mysql_use_result(&mysql);
   
-  /* output table name */
+  /* get a row from query result */
   row = mysql_fetch_row(res);
 
   /* if not found, return false */
   if(row==NULL)  found=FALSE;
 
-  /* if found */
+  /* if found, get the vendor name */
   else {
     strlcpy(vendor, row[0], bufferLength);
     found=TRUE;
   }
 
+  /* free memory area */
   mysql_free_result(res);
   return found;
 }
 
-/******************************************
- The macAddr is already registered
-******************************************/
+/*************************************************/
+/* The macAddr is already registered or not      */
+/* the row having status="D"(deleted) is ignored */
+/* macAddr:(input)                               */
+/*************************************************/
 int isMacAddrFoundInMngDb(char* macAddr){
 
   MYSQL_RES *res=NULL;
@@ -144,10 +149,10 @@ int isMacAddrFoundInMngDb(char* macAddr){
     return FALSE;
   }
   
-  /* store result */
+  /* store query result */
   res = mysql_store_result(&mysql);
 
-  /* output table name */
+  /* get a row from query result */
   row = mysql_fetch_row(res);
   
   /* if found, return true */
@@ -156,13 +161,17 @@ int isMacAddrFoundInMngDb(char* macAddr){
   /* if not found, return false */
   else ret=FALSE;
 
+  /* free memory area */
   mysql_free_result(res);
+  
   return ret;
 }
 
-/******************************************
- The count of registered mac address for the user
-******************************************/
+/******************************************************/
+/* The count of registered mac addresses for the user */
+/* the row having status="D"(deleted) is ignored      */
+/* all-args:(input)                                   */
+/******************************************************/
 int countMacAddrsForUserInMngDb(char* userId, char* extraId){
 
   MYSQL_RES *res=NULL;
@@ -184,13 +193,13 @@ int countMacAddrsForUserInMngDb(char* userId, char* extraId){
     return count;
   }
 
-  /* store result */
+  /* store query result */
   res = mysql_store_result(&mysql);
 
-  /* output table name */
+  /* get a row from query result */
   row = mysql_fetch_row(res);
 
-  /* if found, return values */
+  /* if found, return the count */
   if(row!=NULL){
     strlcpy(countStr, row[0], WORDMAXLN);
     count=atoi(countStr);
@@ -202,21 +211,22 @@ int countMacAddrsForUserInMngDb(char* userId, char* extraId){
   return count;
 }
 
-/******************************************
-register mac address to the management db
-******************************************/
+/***********************************************************/
+/* register mac address and the owner to the management db */
+/* all-args:(input)                                        */
+/***********************************************************/
 int registMacAddrToMngDb(char* macAddr, char* deviceName, char* userId, char* extraId, char* mailAddr){
 
   char queryStr[BUFFMAXLN];
   int count;
 
-   /* if alreay registered (and not deleted yet), return false */
+   /* if alreay registered, return false */
   if(IsMacAddrFoundInMngDb(macAddr)){
     SetMessage(ExistentMacAddr);
     return FALSE;
   }
  
-  /* if the user registered device more than limit, return false */
+  /* if the count of devices for a user exceeds the limit(in conf), return false */
   count=CountMacAddrsForUserInMngDb(userId,extraId);
   if(count >= atoi(GetConfValue("MaxDevices"))){
     SetMessage(DeviceCountOver);
@@ -243,10 +253,13 @@ int registMacAddrToMngDb(char* macAddr, char* deviceName, char* userId, char* ex
   return TRUE;
 }
 
-/*******************************************
- get next mac address from management db
- if end of list, return false
-*******************************************/
+/********************************************************/
+/* get next mac address for the user from management db */
+/* at first call, execute query and return first row    */
+/* from second call, return next row of previous query  */
+/* repeat until return=false (end of list, clear work)  */
+/* userId,extraId:(input), others:(output)              */
+/********************************************************/
 int getNextMacAddrFromMngDb(char* userId, char* extraId, char* macAddress, char* deviceName, char* entryDate, char* limitDate, char* status, char* mailAddress){
 
   static MYSQL_RES *res=NULL;
@@ -297,9 +310,10 @@ int getNextMacAddrFromMngDb(char* userId, char* extraId, char* macAddress, char*
 }
 
 
-/******************************************
- write mac modification log to the management db
-******************************************/
+/***************************************************/
+/* write mac modification log to the management db */
+/* all-args:(input)                                */
+/***************************************************/
 int putMacModifyLogToMngDb(char* userId, char* extraId, char* macAddr, char modifyType){
 
   char queryStr[BUFFMAXLN];
@@ -321,9 +335,12 @@ int putMacModifyLogToMngDb(char* userId, char* extraId, char* macAddr, char modi
   return TRUE;
 }
 
-/******************************************
- The count of mac address modification in last 24 hours
-******************************************/
+/************************************************************/
+/* The count of mac address modification in last 24 hours   */
+/* (the modification count is checked to cope with abuse)   */
+/* all-args:(input)                                         */
+/* indicate either of userID&extraId or macAddress to count */ 
+/************************************************************/
 int countMacModifyPerDayInMngDb(char* userId, char* extraId, char* macAddress){
 
   MYSQL_RES *res=NULL;
@@ -355,13 +372,13 @@ int countMacModifyPerDayInMngDb(char* userId, char* extraId, char* macAddress){
     return count;
   }
 
-  /* store result */
+  /* store query result */
   res = mysql_store_result(&mysql);
 
-  /* output table name */
+  /* get a row from query result */
   row = mysql_fetch_row(res);
 
-  /* if found, return values */
+  /* if found, return count (if not, return large value for safe) */
   if(row!=NULL){
     strlcpy(countStr, row[0], WORDMAXLN);
     count=atoi(countStr);
@@ -373,28 +390,33 @@ int countMacModifyPerDayInMngDb(char* userId, char* extraId, char* macAddress){
   return count;
 }
 
-/******************************************
-delete a mac address registered in the management db
- do not delete, but set the status flag to 'D'
-******************************************/
+/*********************************************************/
+/* delete a mac address registered in the management db  */
+/* in actuality, not delete row, but set the status="D"  */
+/*  when usage log for the address is found in log table */
+/* macAddr:(input)                                       */
+/*********************************************************/
 int delMacAddrFromMngDb(char* macAddr){
 
   char queryStr[BUFFMAXLN];
 
-  /* if the mac data was used, it is preserved for usage log */ 
+  /* if the mac is found in the past session log,        */
+  /* the owner info is needed for the log inspection     */
+  /* thus the info is not deleted, but set as status="D" */
   if(IsSessionFoundInMngDb(macAddr)){
 
     /* prepare query string */
-    /* if session for the mac exists, the row is preserved */
-    /* don't touch device set as status=Inactive */
+    /* don't touch device of status="I"(set Inactive by admin) */
     snprintf(queryStr, BUFFMAXLN, 
 	     "update macaddrs set status='D',limitDate=now() "
 	     " where macAddress='%s' and (status='A' or status='P')", macAddr);
-  }else{
-  
+  }
+
+  /* if mac is not found in past session log, the row is removed */
+  else{
+
     /* prepare query string */
-    /* if session does not exist, the row is removed */
-    /* don't touch device set as status=Inactive */
+    /* don't touch device of status="I"(set Inactive by admin) */
     snprintf(queryStr, BUFFMAXLN, 
 	     "delete from macaddrs "
 	     " where macAddress='%s' and (status='A' or status='P')", macAddr);
@@ -409,10 +431,14 @@ int delMacAddrFromMngDb(char* macAddr){
   return TRUE;
 }
 
-/******************************************
-renew the limit date for a mac address
- registered in the management db
-******************************************/
+/******************************************/
+/* renew the limit date for a mac address */
+/*  in the management db                  */
+/* macAddr:(input)                        */
+/* LimitDate in conf file is a SQL string */
+/* to make a future date                  */
+/* eg, "adddate(now(),interval 1 month)"  */
+/******************************************/
 int renewMacAddrInMngDb(char* macAddr){
 
   char queryStr[BUFFMAXLN];
