@@ -1,6 +1,7 @@
 /**************************************************
 OpengateM - MAC address authentication system 
-header file
+
+header file for OpengateM management programs
 
 Copyright (C) 2011 Opengate Project Team
 Written by Yoshiaki Watanabe
@@ -71,23 +72,22 @@ Email: watanaby@is.saga-u.ac.jp
 #include <openssl/err.h>
 #include <openssl/md5.h>
 
-typedef	void	Sigfunc(int);	/* for signal handlers */
-
+typedef	void Sigfunc(int); /* clarify signal handlers such as 'Sigfunc* func' */
 
 /***************** constants ***********************/
 
 /* Configuration file for opengate */ 
 #define CONFIGFILE "/etc/opengate/opengatemmng.conf"
 
-#define PAMSERVICENAME "opengate"    /* default service name used in PAM */
+#define PAMSERVICENAME "opengate"      /* default service name used in PAM */
 #define RADIUSCONF  "/etc/radius.conf" /* default path to radius.conf */
 
 #define ADDRMAXLN 128      /* maximum address string length */
 #define USERMAXLN 128      /* maximum userid string length */
-#define BUFFMAXLN 1024      /* maximum buffer string length */
+#define BUFFMAXLN 1024     /* maximum buffer string length */
 #define WORDMAXLN 64       /* maximum word length */
-#define FILTERMAXLN 128   /* pcap filter max length */
-#define SIDMAXLN 64       /* maximum sessionID length */
+#define FILTERMAXLN 128    /* pcap filter max length */
+#define SIDMAXLN 64        /* maximum sessionID length */
 
 #define TRUE 1
 #define FALSE 0
@@ -107,7 +107,8 @@ typedef	void	Sigfunc(int);	/* for signal handlers */
 
 extern int debug;
 
-/* errors send to web client */
+/* error IDs send to web client (message for ID is stored in messages.c) */
+/* last ID should be ENDOFLIST */
 enum errs{ExistentMacAddr,DeviceCountOver,IllegalMacAddrForm,
 	  IllegalCharInDevice,EmptyDeviceName,IllegalCharInMailAddr,SuspectNat,
 	  NoInfoInDb,IllegalUserId,IllegalMacAddr,NoService,
@@ -293,3 +294,7 @@ int DisableAlarm(void);
 int PutDataToUdpPort(char* udpServerAddr, char* udpServerPort, char* buff);
 int PutMacAddressToServers(char* macAddress);
 char *GetServicePortStr(char *servName);
+
+/* signal.c */
+Sigfunc* signalx(int signo, Sigfunc* func);
+
